@@ -138,7 +138,12 @@ def compute_metrics_for_numeric_outcome(
         An ordered dictionary containing a key-value pair for R-squared.
     """
     metrics = OrderedDict()
-    metrics["R-squared"] = r2_score(actuals, predictions, sample_weight=weights)
+    non_null_obs = actuals.notnull()
+    metrics["R-squared"] = r2_score(
+        actuals[non_null_obs],
+        predictions[non_null_obs],
+        sample_weight=weights[non_null_obs] if weights else None,
+    )
     return metrics
 
 
@@ -636,6 +641,7 @@ class StateModeler(Modeler):
         objective (str): The model objective appropriate for the outcome type;
             "multiclass" for categorical states and "regression" for numeric
             states.
+        class_values (pd.Int64Index): The state categories.
         num_class (int): The number of state categories or, if the state is
             numeric, None.
     """
@@ -652,7 +658,8 @@ class StateModeler(Modeler):
         if self.data is not None:
             if self.state_col in self.categorical_features:
                 self.objective = "multiclass"
-                self.num_class = len(self.data[self.state_col].cat.categories)
+                self.class_values = self.data[self.state_col].cat.categories
+                self.num_class = len(self.class_values)
             elif self.state_col in self.numeric_features:
                 self.objective = "regression"
                 self.num_class = None
@@ -720,22 +727,26 @@ class StateModeler(Modeler):
                 str(i + 1) + "-period State Probabilities"
                 for i in range(self.n_intervals)
             ]
-            index = np.repeat(
+            ids = np.repeat(
                 self.data[self.config["INDIVIDUAL_IDENTIFIER"]][
                     self.data[self.predict_col]
                 ],
                 forecasts.shape[0],
             )
-            states = np.tile(
-                self.data[self.state_col].cat.categories, forecasts.shape[1]
-            )
+            states = np.tile(self.class_values, forecasts.shape[1])
             forecasts = np.reshape(
                 forecasts,
                 (forecasts.shape[0] * forecasts.shape[1], forecasts.shape[2]),
                 order="F",
             )
+            index = pd.MultiIndex.from_arrays(
+                [ids, states],
+                names=[
+                    self.config["INDIVIDUAL_IDENTIFIER"],
+                    f"Future {self.state_col}",
+                ],
+            )
             forecasts = pd.DataFrame(forecasts, columns=columns, index=index)
-            forecasts[f"Future {self.state_col}"] = states
         else:
             columns = [
                 str(i + 1) + f"-period {self.state_col} Forecast"
@@ -793,6 +804,21 @@ class ExitModeler(StateModeler):
             **kwargs: Arguments to Modeler.__init__().
         """
         super().__init__(exit_col, **kwargs)
+        if self.objective == "multiclass":
+            self.class_values = self.data[
+                (self.data["_duration"] == 0) & (self.data["_event_observed"] == True)
+            ][self.state_col].unique()
+            self.data[self.state_col] = self.data[
+                self.state_col
+            ].cat.reorder_categories(
+                list(self.class_values)
+                + [
+                    cat
+                    for cat in self.data[self.state_col].cat.categories
+                    if cat not in self.class_values
+                ]
+            )
+            self.num_class = len(self.class_values)
         self.exit_col = self.state_col
         if self.data is not None:
             if self.state_col in self.categorical_features:
